Arrhenius package
=================

arrhenius.arrhenius
--------------------------

.. automodule:: arrhenius.arrhenius
   :members:
   :show-inheritance:

arrhenius.arrhenius\_plotting
------------------------------------

.. automodule:: arrhenius.arrhenius_plotting
   :members:
   :undoc-members:
   :show-inheritance:
